@@ -15,7 +15,7 @@ use Readonly;
 Readonly::Scalar my $EMPTY_STR => q{};
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Constructor.
 sub new {
@@ -380,8 +380,17 @@ L<Readonly>.
 
 =head1 SEE ALSO
 
-L<Cnf>,
-L<Cnf::More>.
+=over
+
+=item L<Config::Dot>
+
+Module for simple configure file parsing.
+
+=item L<Config::Utils>
+
+Common config utilities.
+
+=back
 
 =head1 REPOSITORY
 
@@ -395,10 +404,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD 2-Clause License
+ © 2011-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
